@@ -3,8 +3,9 @@ from pymongo.database import Database
 from pymongo.collection import Collection
 from IPython.core.magic import Magics, magics_class, cell_magic, line_magic, needs_local_scope
 from IPython.config.configurable import Configurable
-from helps import DB_METHODS
-from parse import parse
+from helps import *
+from util import parse, print_json, print_cursor, find_query_pymongo, insert_query_pymongo
+
 
 @magics_class
 class MongoDB(Magics, Configurable):
@@ -25,7 +26,7 @@ class MongoDB(Magics, Configurable):
         if line:
             uri = line
         else:
-            uri = 'mongodb://localhost:27017'
+            uri = 'mongodb://127.0.0.1:27017'
         self._conn = MongoClient(uri)
         # add db and collection property to object for autocomplete.
         for db in self._conn.database_names():
@@ -42,8 +43,7 @@ class MongoDB(Magics, Configurable):
         if self._conn:
             return self._conn.database_names()
         else:
-            print "[ERROR] please connect to mongodb using %mongo_connect"
-            return line
+            return "[ERROR] please connect to mongodb using %mongo_connect"
 
     @line_magic('show_collections')
     def show_collections(self, line):
@@ -66,9 +66,49 @@ class MongoDB(Magics, Configurable):
             return "[ERROR] connect mongodb before %insert"
         parsed = parse('%s\n%s' % (line, cell), self)
         try:
-            parsed['collection'].insert(json.loads(parsed['data']))
-        except:
-            return "[ERROR] fail to insert data"
+            data = insert_query_pymongo(parsed['data'])
+            parsed['collection'].insert(data)
+        except Exception as e:
+            return "[ERROR] fail to insert data", e
+
+    @line_magic('drop')
+    @cell_magic('drop')
+    def drop(self, line):
+        if not self._conn:
+            return "[ERROR] connect mongodb before %delete"
+        if not line:
+            return "[ERROR] please use like %delete db.collection or %delete db"
+        db_col = line.split('.')
+        if db_col.__len__() > 2:
+            return "[ERROR] please use like %delete db.collection or %delete db"
+        elif db_col.__len__() == 2:
+            Database(self._conn, db_col[0]).drop_collection(db_col[1])
+        else:
+            self._conn.drop_database(db_col[0])
+
+    @line_magic('print')
+    @cell_magic('print')
+    def mongo_print(self, line, cell=''):
+        if not self._conn:
+            return "[ERROR] connect mongodb before %print"
+        parsed = parse('%s\n%s' % (line, cell), self)
+        # print db.collection.find()
+        try:
+            result = print_json(parsed['data'])
+        except Exception:
+            return "[ERROR] fail to print about", parsed['data']
+
+    @line_magic('find')
+    @cell_magic('find')
+    def mongo_find(self, line, cell=''):
+        if not self._conn:
+            return "[ERROR] connect mongodb before %find"
+        parsed = parse('%s\n%s' % (line, cell), self)
+        try:
+            query = find_query_pymongo(parsed['data'])
+            return print_cursor(parsed['collection'].find(query))
+        except Exception as e:
+            return "[ERROR] fail to query ", e
 
     @line_magic('help')
     def help_message(self, line):
@@ -78,21 +118,9 @@ class MongoDB(Magics, Configurable):
         elif line == 'collection':
             message += COLLECTION_METHODS
         else:
-            message += """
-                %help db             help on db methods
-                %help collection     help on collection methods
-
-                %mongo_connect <host>       connect to <host> mongodb
-                %show_dbs                   show database names
-                %show_collections <dbname>  show collections on <dbname>
-                %insert <dbname>.<collection name> {json data}
-                                            insert data to db.collection
-                %%insert <dbname>.<collection name>
-                {json data} or {json data list}
-                                            insert data to db.collection
-            """
+            message += HELP_MESSAGE
         print message
 
+
 def load_ipython_extension(ipython):
     ipython.register_magics(MongoDB)
-
